Histograms in OpenCV {#tutorial_py_table_of_contents_histograms}
====================

-   @subpage tutorial_py_histogram_begins

    Learn to find and draw Contours

-   @subpage tutorial_py_histogram_equalization

    Learn to Equalize Histograms to get better contrast for images

-   @subpage tutorial_py_2d_histogram

    Learn to find and plot 2D Histograms

-   @subpage tutorial_py_histogram_backprojection

    Learn histogram backprojection to segment colored objects
